aboutsummaryrefslogtreecommitdiff
path: root/src/policy/feerate.h
diff options
context:
space:
mode:
authorMarcoFalke <falke.marco@gmail.com>2021-05-04 10:14:12 +0200
committerMarcoFalke <falke.marco@gmail.com>2021-05-18 07:13:25 +0200
commitfafd121026c4f1e25d498983e4f88c119516552b (patch)
tree306dd432b7e300b526bc546ff5b81b2941b899ca /src/policy/feerate.h
parentc8571486364d6e9ca8c86bd1c81e230ca64f8904 (diff)
downloadbitcoin-fafd121026c4f1e25d498983e4f88c119516552b.tar.xz
refactor: Make CFeeRate constructor architecture-independent
Diffstat (limited to 'src/policy/feerate.h')
-rw-r--r--src/policy/feerate.h11
1 files changed, 4 insertions, 7 deletions
diff --git a/src/policy/feerate.h b/src/policy/feerate.h
index 0e4f9914b8..d296d32774 100644
--- a/src/policy/feerate.h
+++ b/src/policy/feerate.h
@@ -39,20 +39,17 @@ public:
// We've previously had bugs creep in from silent double->int conversion...
static_assert(std::is_integral<I>::value, "CFeeRate should be used without floats");
}
- /** Constructor for a fee rate in satoshis per kvB (sat/kvB). The size in bytes must not exceed (2^63 - 1).
+ /** Constructor for a fee rate in satoshis per kvB (sat/kvB).
*
* Passing an nBytes value of COIN (1e8) returns a fee rate in satoshis per vB (sat/vB),
* e.g. (nFeePaid * 1e8 / 1e3) == (nFeePaid / 1e5),
* where 1e5 is the ratio to convert from BTC/kvB to sat/vB.
- *
- * @param[in] nFeePaid CAmount fee rate to construct with
- * @param[in] nBytes size_t bytes (units) to construct with
*/
- CFeeRate(const CAmount& nFeePaid, size_t nBytes);
+ CFeeRate(const CAmount& nFeePaid, uint32_t num_bytes);
/**
* Return the fee in satoshis for the given size in bytes.
*/
- CAmount GetFee(size_t nBytes) const;
+ CAmount GetFee(uint32_t num_bytes) const;
/**
* Return the fee in satoshis for a size of 1000 bytes
*/
@@ -39,20 +39,17 @@ public:
*
- * Passing an nBytes value of COIN (1e8) returns a fee rate in satoshis per vB (sat/vB),
+ * Passing a num_bytes value of COIN (1e8) returns a fee rate in satoshis per vB (sat/vB),
* e.g. (nFeePaid * 1e8 / 1e3) == (nFeePaid / 1e5),
* where 1e5 is the ratio to convert from BTC/kvB to sat/vB.